@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Mock data creation
 
-our $VERSION = '0.1601';
+our $VERSION = '0.1700';
 
 use strict;
 use warnings;
@@ -17,7 +17,6 @@ use Data::SimplePassword;
 use Date::Range;
 use Date::Simple qw(date today);
 use Image::Dot;
-use List::Util qw(shuffle);
 use Mock::Person;
 use Statistics::Distributions;
 use Text::Password::Pronounceable;
@@ -247,7 +246,7 @@ sub distributor {
     $args{dof}  //= DOF;
     $args{N}    ||= NDATA;
 
-    # Separate numerator/denominator for F degs-of-freedm.
+    # Separate numerator/denominator for F degs-of-freedom.
     my $e = 1;
     ($args{dof}, $e) = split(/\//, $args{dof}) if $args{type} eq 'f';
 
@@ -284,12 +283,6 @@ sub distributor {
 }
 
 
-sub shuffler {
-    my @items = @_ ? @_ : ('a' .. 'j');
-    return [ shuffle(@items) ];
-}
-
-
 sub string_ranger {
     my %args = @_;
     # Set defaults.
@@ -398,7 +391,7 @@ Mock::Populate - Mock data creation
 
 =head1 VERSION
 
-version 0.1601
+version 0.1700
 
 =head1 SYNOPSIS
 
@@ -406,17 +399,16 @@ version 0.1601
   # * Call each function below with Mock::Populate::foo(...
   my $n      = 5;
   my $offset = 11;
-  my $ids    = number_ranger(start => 1, end => 1001, prec => 0, random => 0);
+  my $ids    = number_ranger(start => 1, end => $n, prec => 0, random => 0);
   my $money  = number_ranger(start => 1000, end => 5000, prec => 2, N => $n);
   my $create = date_ranger(start => '1900-01-01', end => '2020-12-31', N => $n);
   my $modify = date_modifier($offset, @$create);
-  my $times  = time_ranger(stamp => 1, start => '01:02:03', end =>'23:59:59', N => $n);
+  my $times  = time_ranger(start => '01:02:03', end =>'23:59:59', stamp => 1, N => $n);
   my $people = name_ranger(gender => 'f', N => $n);
   my $email  = email_ranger(@$people);
-  my $shuff  = shuffler(qw(foo bar baz goo ber buz));
   my $stats  = distributor(type => 'u', prec => 4, dof => 2, N => $n);
   my $string = string_ranger(length => 32, type => 'base64', N => $n);
-  my $imgs   = image_ranger(size => 10, N => $n);  # size is density, not dimension
+  my $imgs   = image_ranger(N => $n);
   my $coll   = collate($ids, $people, $email, $create, $times);
 
 =head1 DESCRIPTION
@@ -550,14 +542,6 @@ This function uses single letter identifiers:
   s: Student's T distribution
   f: F distribution
 
-=head2 shuffler()
-
-  $results = shuffler(@items)
-
-Return a shuffled list of B<items>.  The items are optional.  The defaults are:
-
-  items: a b c d e f g h i j
-
 =head2 string_ranger()
 
   $results = string_ranger(
@@ -620,8 +604,6 @@ L<Date::Simple>
 
 L<Image::Dot>
 
-L<List::Util>
-
 L<Mock::Person>
 
 L<Statistics::Distributions>
@@ -634,25 +616,6 @@ L<Time::Local>
 
 L<Data::Random> does nearly the exact same thing. Whoops!
 
-=head1 TO DO
-
-Implement dirty-data randomizing.
-
-  unexpected formats: iso-8859-1, utf-16, windows codepage,
-  BOM (byte order marker),
-  broken unicode,
-  garbled binary,
-  \r and \n variations,
-  commas or $ in currencies ("format fuckups"),
-  bad JSON,
-  broken XML,
-  bad ' and " in CSV,
-  statistical outliers,
-  time-series drops and spikes,
-  duplicate data,
-  missing data,
-  truncated data,
-
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
